# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.order_confirmation import OrderConfirmation  # noqa: E501
from swagger_client.rest import ApiException


class TestOrderConfirmation(unittest.TestCase):
    """OrderConfirmation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOrderConfirmation(self):
        """Test OrderConfirmation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.order_confirmation.OrderConfirmation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
