# coding: utf-8

"""
    Kalshi Trade API

    This documentation describes Kalshi's trading API (known as Trade API v2). By using this API, you agree to Kalshi's Developer Agreement (https://kalshi.com/developer-agreement).  # noqa: E501

    OpenAPI spec version: 2.0.0
    Contact: support@kalshi.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kalshi_python
from kalshi_python.api.portfolio_api import PortfolioApi  # noqa: E501
from kalshi_python.rest import ApiException


class TestPortfolioApi(unittest.TestCase):
    """PortfolioApi unit test stubs"""

    def setUp(self):
        self.api = PortfolioApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_batch_cancel_orders(self):
        """Test case for batch_cancel_orders

        BatchCancelOrders  # noqa: E501
        """
        pass

    def test_batch_create_orders(self):
        """Test case for batch_create_orders

        BatchCreateOrders  # noqa: E501
        """
        pass

    def test_cancel_order(self):
        """Test case for cancel_order

        CancelOrder  # noqa: E501
        """
        pass

    def test_create_order(self):
        """Test case for create_order

        CreateOrder  # noqa: E501
        """
        pass

    def test_decrease_order(self):
        """Test case for decrease_order

        DecreaseOrder  # noqa: E501
        """
        pass

    def test_get_balance(self):
        """Test case for get_balance

        GetBalance  # noqa: E501
        """
        pass

    def test_get_fills(self):
        """Test case for get_fills

        GetFills  # noqa: E501
        """
        pass

    def test_get_order(self):
        """Test case for get_order

        GetOrder  # noqa: E501
        """
        pass

    def test_get_orders(self):
        """Test case for get_orders

        GetOrders  # noqa: E501
        """
        pass

    def test_get_portfolio_settlements(self):
        """Test case for get_portfolio_settlements

        GetPortfolioSettlements  # noqa: E501
        """
        pass

    def test_get_positions(self):
        """Test case for get_positions

        GetPositions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
